@@ -2,14 +2,13 @@ from __future__ import annotations
 
 import contextlib
 
-import async_timeout
 from bleak.backends.bluezdbus import defs
 from bleak.backends.device import BLEDevice
-from dbus_fast.aio import MessageBus
-from dbus_fast.constants import BusType
 from dbus_fast.message import Message
 
-DISCONNECT_TIMEOUT = 5
+from .bleak_manager import get_global_bluez_manager_with_timeout
+from .const import DISCONNECT_TIMEOUT
+from .util import asyncio_timeout
 
 
 async def disconnect_devices(devices: list[BLEDevice]) -> None:
@@ -21,10 +20,15 @@ async def disconnect_devices(devices: list[BLEDevice]) -> None:
     ]
     if not valid_devices:
         return
-    bus = await MessageBus(bus_type=BusType.SYSTEM, negotiate_unix_fd=True).connect()
-    for device in devices:
+    if not (bluez_manager := await get_global_bluez_manager_with_timeout()):
+        return
+    bus = bluez_manager._bus
+    for device in valid_devices:
+        # https://bleak.readthedocs.io/en/latest/troubleshooting.html#id4
+        # Try to remove the device as well in the hope that it will
+        # clear the disk cache of the device.
         with contextlib.suppress(Exception):
-            async with async_timeout.timeout(DISCONNECT_TIMEOUT):
+            async with asyncio_timeout(DISCONNECT_TIMEOUT):
                 await bus.call(
                     Message(
                         destination=defs.BLUEZ_SERVICE,
@@ -33,4 +37,3 @@ async def disconnect_devices(devices: list[BLEDevice]) -> None:
                         member="Disconnect",
                     )
                 )
-    bus.disconnect()
